unit Common.Logging.Classes;

interface

uses
  System.SysUtils, Common.Logging;

type
  ///<summary>Logger for null-Object-Pattern<summary>
  TNullLogger = class(TInterfacedObject,ILogger)
  public
    procedure Log(level: TLogLevel; const msg: String);
    procedure Error(const text: String; E: Exception = nil);
    procedure Info(const text: String);
    procedure Warn(const text: String);
    procedure Debug(const text: String);
  end;


  ///<summary>Base class for Ref-Counted-Implementations with Logger<summary>
  TLoggedInterfacedObject = class(TInterfacedObject)
  private
    FLogger: ILogger;
  protected
    ///<summary>a Logger is always there</summary>
    property Logger: ILogger read FLogger;
  public
    constructor Create(const logger: ILogger);
    destructor Destroy; override;
  end;


  ///<summary>Base class for simmple logged class<summary>
  TLoggedObject = class(TObject)
  private
    FLogger: ILogger;
  protected
    ///<summary>a Logger is always there</summary>
    property Logger: ILogger read FLogger;
  public
    constructor Create(const logger: ILogger);
    destructor Destroy; override;
  end;



implementation


{ TNullLogger }


procedure TNullLogger.Debug(const text: String);
begin
  // nothing to do
end;

procedure TNullLogger.Error(const text: String; E: Exception);
begin
  // nothing to do
end;

procedure TNullLogger.Info(const text: String);
begin
  // nix tun
end;

procedure TNullLogger.Log(level: TLogLevel; const msg: String);
begin
  // nothing to do
end;

procedure TNullLogger.Warn(const text: String);
begin
  // nothing to do
end;


{ TLoggedInterfacedObject }

constructor TLoggedInterfacedObject.Create(const logger: Ilogger);
begin
  inherited Create;
  // if there is no logger, we create a null-logger
  if logger = nil then
    FLogger := TNullLogger.Create
  else
    FLogger := logger;
end;

destructor TLoggedInterfacedObject.Destroy;
begin
  FLogger := nil;
  inherited;
end;

{ TLoggedObject }

constructor TLoggedObject.Create(const logger: ILogger);
begin
  inherited Create;
  // if there is no logger, we create a null-logger
  if logger = nil then
    FLogger := TNullLogger.Create
  else
    FLogger := logger;
end;

destructor TLoggedObject.Destroy;
begin
  FLogger := nil;
  inherited;
end;

end.
