unit Common.Logging.Impl.Console;

interface

uses
  System.SysUtils, Common.Logging;

type
  TConsoleLogger = class(TInterfacedObject,ILogger)
  public
    procedure Log(level: TLogLevel; const text: String);
    procedure Error(const text: String; E: Exception = nil);
    procedure Info(const text: String);
    procedure Warn(const text: String);
    procedure Debug(const text: String);
  end;

implementation

const
  sLogLevels: Array[TLogLevel] of string = ('Debug', 'Info', 'Warn', 'Error');

{ TConsoleLogger }

procedure TConsoleLogger.Log(level: TLogLevel; const text: String);
begin
  Writeln(sLogLevels[level] + ': ' + text);
end;

procedure TConsoleLogger.Debug(const text: String);
begin
  Log(llDebug, text);
end;


procedure TConsoleLogger.Error(const text: String; E: Exception);
begin
   if Assigned(E) then
    Log(llError, text + Format('Exception %s with Message %s',[E.ClassName,E.Message]))
  else
    Log(llError, text);
end;


procedure TConsoleLogger.Info(const text: String);
begin
  Log(llInfo, text);
end;


procedure TConsoleLogger.Warn(const text: String);
begin
  Log(llWarn, text);
end;


end.
