unit Shopping.Types;

interface

uses
  System.Classes, System.SysUtils, System.Types, System.Generics.Collections,
  Common.Exceptions;

type
  TBasketItem = record
    ItemName: string;
    Description: string;
    Count: Integer;
    Price: Currency;
  end;

  TBasketItemsArray = TArray<TBasketItem>;

  TBasketContent = record
    CustomerId: string;
    BasketItems: TBasketItemsArray;
    VoucherCodes: TStringDynArray;
  end;



  /// <summary>IBasketLoader
  /// </summary>
  IBasketLoader = interface(IInvokable)
    /// <summary>loads Items of Shoppingbasket </summary>
    /// <remarks>different implementations could use different sources and formats///
    /// </remarks>
    /// <returns>Content of basket</returns>
    /// <param name="cartID">Unique Id of Cart to load</param>
    /// <exception cref="ELoadError">when Technical Exceptions occur on loading</exception>
    /// <exception cref="ECartNotFound">when a cart with given id could not be found</exception>
    function LoadItems(const cartID: string): TBasketContent;
  end;

type
  EInvalidVoucher =  class(ELogicalException);

  /// <summary>interface to validate an calculate the code of a voucher</summary>
  IVoucherCalculator = interface(IInvokable)
    /// <summary>validates a voucher</summary>
    /// <returns>value of given voucher code</returns>
    /// <param name="itemsvalue">value of items in basket</param>
    /// <param name="customerId">Unique Id for customer</param>
    /// <param name="voucher">code for a voucher</param>
    /// <exception cref="EInvalidVoucher">is raised if given voucher is invalid (code already used or invalid code etc)</exception>
    /// <exception cref="ETechnicalException">are raised when calculation fails due to internal errors</exception>
    function CalculateVoucher(const itemsvalue: Currency; const customerId, voucher: string): Currency;
  end;



implementation

end.
